Create a file name unique for a project, along with timestamp.
Source:R/proj.R
proj_create_path_dataset.RdYou use this when you want to create a dataset when using proj_create_dataset().
R/proj.R
proj_create_path_dataset.RdYou use this when you want to create a dataset when using proj_create_dataset().